%define upstream_name       Class-InsideOut
%define upstream_version 1.14

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 4
License:    GPL or Artistic
Group:      Development/Perl
Summary:    A safe, simple inside-out object construction kit
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Config/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Class::ISA)
BuildRequires: perl(Config)
BuildRequires: perl(DynaLoader)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Find)
BuildRequires: perl(File::Spec)
BuildRequires: perl(File::Spec::Functions)
BuildRequires: perl(File::Temp)
BuildRequires: perl(IO::File)
BuildRequires: perl(List::Util)
BuildRequires: perl(Scalar::Util) >= 1.90.0
BuildRequires: perl(Storable)
BuildRequires: perl(Test::More) >= 0.450.0
BuildRequires: perl(XSLoader)
BuildRequires: perl(overload)
BuildRequires: perl(strict)
BuildRequires: perl(threads)
BuildRequires: perl(vars)
BuildRequires: perl(warnings)
BuildRequires: perl-devel
BuildArch:  noarch

%description
This is a simple, safe and streamlined toolkit for building inside-out objects.
Unlike most other inside-out object building modules already on CPAN, this
module aims for minimalism and robustness:

* Does not require derived classes to subclass it
* Uses no source filters, attributes or CHECK blocks
* Supports any underlying object type including black-box inheritance
* Does not leak memory on object destruction
* Overloading-safe
* Thread-safe for Perl 5.8.5 or better
* mod_perl compatible
* Makes no assumption about inheritance or initializer needs

It provides the minimal support necessary for creating safe inside-out objects
and generating flexible accessors.

%prep
%setup -q -n %{upstream_name}-%{upstream_version} 

%build
%__perl Makefile.PL -n INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc CONTRIBUTING.mkdn Changes LICENSE META.json META.yml MYMETA.yml README examples
%{_mandir}/man3/*
%{perl_vendorlib}/Class


%changelog
* Sun Mar 20 2022 umeabot <umeabot> 1.140.0-4.mga9
+ Revision: 1808549
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 1.140.0-3.mga8
+ Revision: 1503575
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 1.140.0-2.mga7
+ Revision: 1282262
- Mageia 7 Mass Rebuild

* Sat Jul 29 2017 sander85 <sander85> 1.140.0-1.mga7
+ Revision: 1132397
- update to 1.14

* Sat Jun 18 2016 pterjan <pterjan> 1.130.0-7.mga6
+ Revision: 1023972
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 1.130.0-6.mga6
+ Revision: 949073
- Mageia 6 Mass Rebuild

* Sun Oct 19 2014 umeabot <umeabot> 1.130.0-5.mga5
+ Revision: 788907
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.130.0-4.mga5
+ Revision: 742059
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.130.0-3.mga5
+ Revision: 683920
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.130.0-2.mga4
+ Revision: 526832
- Mageia 4 Mass Rebuild

* Fri Jun 07 2013 jquelin <jquelin> 1.130.0-1.mga4
+ Revision: 438866
- update to 1.13

* Thu Jan 24 2013 sander85 <sander85> 1.110.0-1.mga3
+ Revision: 392090
- Fix URL
+ jquelin <jquelin>
- update to 1.11
- magpie fix (get correct buildrequires)
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 22 2011 jquelin <jquelin> 1.100.0-1.mga1
+ Revision: 31782
- mageia rebuild
- imported package perl-Class-InsideOut


* Tue Aug 25 2009 Jérôme Quelin <jquelin@mandriva.org> 1.100.0-1mdv2010.0
+ Revision: 421133
- update to 1.10

* Sat Aug 22 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.90.0-1mdv2010.0
+ Revision: 419636
- new perl version macro
- fix summary and description

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 1.09-3mdv2009.0
+ Revision: 255988
- rebuild

* Tue Jan 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.09-1mdv2008.1
+ Revision: 152962
- update to new version 1.09
- update to new version 1.09

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 06 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.08-1mdv2008.1
+ Revision: 106602
- import perl-Class-InsideOut


